@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
+# cython: language_level=3, always_allow_keywords=True
 
-## Copyright 2009-2010 by LivingLogic AG, Bayreuth/Germany
-## Copyright 2009-2010 by Walter Dörwald
+## Copyright 2009-2019 by LivingLogic AG, Bayreuth/Germany
+## Copyright 2009-2019 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
-## See ll/__init__.py for the license
+## See ll/xist/__init__.py for the license
 
 
 __docformat__ = "reStructuredText"
 
-import os, optparse, collections, contextlib
+import os, collections, contextlib
 
 from ll import url
 from ll.xist import xsc, sims
@@ -48,11 +49,11 @@ else:
 	roles.register_generic_role("meth", meth)
 	en.roles["meth"] = "meth"
 
-	class var(nodes.literal):
+	class obj(nodes.literal):
 		pass
 
-	roles.register_generic_role("var", var)
-	en.roles["var"] = "var"
+	roles.register_generic_role("obj", obj)
+	en.roles["obj"] = "obj"
 
 	class exc(nodes.literal):
 		pass
@@ -176,7 +177,8 @@ class BaseElement(xsc.Element):
 		class class_(xsc.TextAttr):
 			"``class`` is used to transmit individuality information forward."
 			xmlname = "class"
-	
+
+
 # Root Element
 class document(BaseElement):
 	class Attrs(BaseElement.Attrs):
@@ -388,19 +390,28 @@ class field_body(BaseElement):
 
 
 class option_list(BaseElement):
-	pass
+	def convert(self, converter):
+		e = doc.dl(self.content)
+		return e.convert(converter)
 
 
 class option_list_item(BaseElement):
-	pass
+	def convert(self, converter):
+		e = self.content
+		return e.convert(converter)
 
 
 class option_group(BaseElement):
-	pass
-
-
-class option(BaseElement):
-	pass
+	def convert(self, converter):
+		e = doc.dt()
+		for o in self[option]:
+			if e:
+				e.append(", ")
+			e2 = doc.lit(doc.option(o[option_string][0].content))
+			for oa in o[option_argument]:
+				e2.append("=", oa.content)
+			e.append(e2)
+		return e.convert(converter)
 
 
 class option_string(BaseElement):
@@ -414,7 +425,9 @@ class option_argument(BaseElement):
 
 
 class description(BaseElement):
-	pass
+	def convert(self, converter):
+		e = doc.dd(self.content)
+		return e.convert(converter)
 
 
 class literal_block(BaseElement):
@@ -561,7 +574,8 @@ class system_message(BaseElement):
 
 	def convert(self, converter):
 		# A warning has already been issued by docutils, we don't have to do anything
-		return xsc.Null 
+		return xsc.Null
+
 
 class raw(BaseElement):
 	class Attrs(BaseElement.Attrs):
@@ -628,11 +642,11 @@ class meth(BaseElement):
 		return e.convert(converter)
 
 
-class var(BaseElement):
+class obj(BaseElement):
 	model = sims.NoElements()
 
 	def convert(self, converter):
-		e = doc.var(self.content)
+		e = doc.obj(self.content)
 		return e.convert(converter)
 
 
@@ -925,11 +939,10 @@ class ReSTConversionWarning(Warning):
 	pass
 
 
-class ReSTConverter(object):
+class ReSTConverter:
 	def __init__(self):
 		from ll.xist.ns import doc, abbr
-		self.namedrefs = collections.defaultdict()
-		self.namedrefs.default_factory = list
+		self.namedrefs = collections.defaultdict(list)
 		self.unnamedrefs = []
 		self.doc = doc
 		self.abbr = abbr
@@ -999,16 +1012,18 @@ class ReSTConverter(object):
 			warnings.warn(ReSTConversionWarning(str(node)))
 			return xsc.Null # ignore system messages
 		else:
-			raise TypeError("can't handle %r" % node.__class__)
+			raise TypeError(f"can't handle {node.__class__!r}")
 
 
 def fromstring(string, base=None, **options):
-	doc = core.publish_doctree(string, source_path=base, settings_overrides=options)
+	realoptions = dict(tab_width=3)
+	realoptions.update(options)
+	doc = core.publish_doctree(string, source_path=base, settings_overrides=realoptions) # This requires docutils
 	elements = globals()
 
 	def toxist(node):
 		if isinstance(node, nodes.Text):
-			return xsc.Text(unicode(node.astext()))
+			return xsc.Text(str(node.astext()))
 		else:
 			e = elements[node.__class__.__name__](toxist(child) for child in node.children)
 			e.startloc = xsc.Location(node.source, node.line)
