@@ -143,7 +143,7 @@ def _transport_js_v8(obj, indent):
 	(this requires an installed ``d8`` shell from V8 (http://code.google.com/p/v8/))
 	"""
 	dump = ul4on.dumps(obj, indent=indent)
-	js = f"obj = ul4on.loads({ul4c._asjson(dump)});\nprint(ul4on.dumps(obj, {ul4c._asjson(indent)}));\n"
+	js = f"obj = ul4.loads({ul4c._asjson(dump)});\nprint(ul4.dumps(obj, {ul4c._asjson(indent)}));\n"
 	f = sys._getframe(1)
 	print(f"Testing UL4ON via V8 ({f.f_code.co_filename}, line {f.f_lineno:,}):")
 	print(js)
@@ -151,7 +151,7 @@ def _transport_js_v8(obj, indent):
 		f.write(js.encode("utf-8"))
 		f.flush()
 		dir = os.path.expanduser("~/checkouts/LivingLogic.Javascript.ul4")
-		cmd = f"d8 {dir}/ul4.js {f.name}"
+		cmd = f"d8 {dir}/dist/umd/ul4.js {f.name}"
 		result = subprocess.run(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
 	stdout = result.stdout.decode("utf-8")
 	stderr = result.stderr.decode("utf-8")
@@ -182,10 +182,9 @@ def _transport_js_node(obj, indent):
 	"""
 	dump = ul4on.dumps(obj, indent=indent)
 	js = f"""
-		const ll = require('{home}/checkouts/LivingLogic.Javascript.ul4/ul4.min');
-		const ul4on = ll.ul4on;
-		obj = ul4on.loads({ul4c._asjson(dump)});
-		console.log(JSON.stringify(ul4on.dumps(obj, {ul4c._asjson(indent)})));
+		const ul4 = require('{home}/checkouts/LivingLogic.Javascript.ul4/dist/umd/ul4');
+		var obj = ul4.loads({ul4c._asjson(dump)});
+		console.log(JSON.stringify(ul4.dumps(obj, {ul4c._asjson(indent)})));
 	"""
 	f = sys._getframe(1)
 	print(f"Testing UL4ON via Node ({f.f_code.co_filename}, line {f.f_lineno:,}):")
@@ -249,7 +248,7 @@ def java_formatsource(string):
 
 def java_runsource(source):
 	"""
-	Compile the Java source :obj:`source`, run it and return the output
+	Compile the Java source ``source``, run it and return the output
 	"""
 	source = f"""
 	public class UL4ONTest
@@ -334,9 +333,9 @@ all_transports = [
 
 
 def pytest_generate_tests(metafunc):
-	if "t" in metafunc.funcargnames:
+	if "t" in metafunc.fixturenames:
 		metafunc.parametrize("t", [t for (id, t) in all_transports], ids=[id for (id, t) in all_transports])
-	if "oracle" in metafunc.funcargnames:
+	if "oracle" in metafunc.fixturenames:
 		metafunc.parametrize("oracle", [oracle for (id, oracle) in all_oracles], ids=[id for (id, oracle) in all_oracles])
 
 
