@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 # cython: language_level=3, always_allow_keywords=True
 
-## Copyright 1999-2017 by LivingLogic AG, Bayreuth/Germany
-## Copyright 1999-2017 by Walter Dörwald
+## Copyright 1999-2019 by LivingLogic AG, Bayreuth/Germany
+## Copyright 1999-2019 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
@@ -360,7 +360,7 @@ def test_attributekeysvaluesitems():
 def test_attributeswithoutnames():
 	node = html.h1(
 		"gurk",
-		{xml.Attrs.lang: "de", xml.Attrs.base: "http://www.livinglogic.de/"},
+		{xml.Attrs.lang: "de", xml.Attrs.base: "http://python.livinglogic.de/"},
 		lang="de",
 		style="color: #fff",
 		align="right",
